ConnectedCamerasManager

Struct ConnectedCamerasManager 

pub struct ConnectedCamerasManager { /* private fields */ }
keeps track of connected camera state

There should be a single call to ::new() made in the app. Then, clone() can be called to copy the outer wrapper which links to the actual inner manager via Arc<Mutex<_>>.

Implementations

Source

impl ConnectedCamerasManager

pub fn new( recon: &Option<FlydraMultiCameraSystem<MyFloat>>, all_expected_cameras: BTreeSet<RawCamName>, signal_all_cams_present: Arc<AtomicBool>, signal_all_cams_synced: Arc<AtomicBool>, periodic_signal_period_usec: Option<f64>, predefined_cam_nums: Option<BTreeMap<RawCamName, CamNum>>, ) -> Self

pub fn reset_sync_data(&mut self)

The cameras are being (re)synchronized. Clear all inner data and reset camera numbers.

pub fn set_cam_changed_callback( &mut self, f: Box<dyn ConnectedCamCallback>, ) -> Option<Box<dyn ConnectedCamCallback>>

Set callback to be called when connected cameras or their state changes

pub fn new_single_cam( raw_cam_name: &RawCamName, http_camserver_info: &BuiServerInfo, recon: &Option<FlydraMultiCameraSystem<MyFloat>>, camera_periodic_signal_period_usec: Option<f64>, ) -> Self

Alternative constructor for use in case of a single camera.

See new and register_new_camera for the case when multiple cameras will be added.

pub fn remove(&mut self, raw_cam_name: &RawCamName)

pub fn register_new_camera( &mut self, raw_cam_name: &RawCamName, http_camserver_info: &BuiServerInfo, camera_periodic_signal_period_usec: Option<f64>, ) -> Result<(), &'static str>

This is called to register a camera when it connects to the mainbrain.

See new_single_cam for the case when only a single camera will be added.

pub fn got_new_frame_live<F>( &self, packet: &FlydraRawUdpPacket, sync_pulse_pause_started_arc: &Arc<RwLock<Option<SyncStart>>>, send_new_frame_offset: F, trigger_cfg: &TriggerType, ) -> Option<SyncFno>
where F: FnMut(u64),

Register that a new frame was received

Returns synced frame number

pub fn get_raw_cam_name(&self, cam_num: CamNum) -> Option<RawCamName>

pub fn all_raw_cam_names(&self) -> Vec<RawCamName>

pub fn http_camserver_info( &self, raw_cam_name: &RawCamName, ) -> Option<BuiServerInfo>

pub fn cam_num(&self, raw_cam_name: &RawCamName) -> Option<CamNum>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool