pub struct CoordProcessor {
pub cam_manager: ConnectedCamerasManager,
pub recon: Option<FlydraMultiCameraSystem<MyFloat>>,
pub braidz_write_tx: SingletonSender<SaveToDiskMsg>,
pub writer_join_handle: JoinHandle<Result<()>>,
/* private fields */
}Fields
cam_manager: ConnectedCamerasManagerrecon: Option<FlydraMultiCameraSystem<MyFloat>>braidz_write_tx: SingletonSender<SaveToDiskMsg>Channel to send messages to the writing thread.
writer_join_handle: JoinHandle<Result<()>>Implementations
Sourceimpl CoordProcessor
impl CoordProcessor
pub fn new( cfg: CoordProcessorConfig, cam_manager: ConnectedCamerasManager, recon: Option<FlydraMultiCameraSystem<MyFloat>>, metadata_builder: BraidMetadataBuilder, ) -> Result<Self>
pub fn add_listener( &mut self, model_server: Sender<(SendType, TimeDataPassthrough)>, )
Sourcepub async fn consume_stream<S>(
self,
frame_data_rx: S,
expected_framerate: Option<f32>,
) -> Result<JoinHandle<Result<()>>>
pub async fn consume_stream<S>( self, frame_data_rx: S, expected_framerate: Option<f32>, ) -> Result<JoinHandle<Result<()>>>
Consume the CoordProcessor and the input stream.
Returns a future that completes when done. This is basically the “main loop”. It is async, though, and yields many times throughout this execution.
Upon completion, returns a std::thread::JoinHandle from a spawned writing thread. To ensure data is completely saved, this should be driven to completion before ending the process.