pub struct FrameDataAndPoints {
pub frame_data: FrameData,
pub points: Vec<NumberedRawUdpPoint>,
}Expand description
image processing results from a single camera on a single frame
This is essentially a fixed up version of the data received from the flydra UDP packet on each frame from each camera.
Fields
frame_data: FrameDatapoints: Vec<NumberedRawUdpPoint>Trait Implementations
Sourceimpl Clone for FrameDataAndPoints
impl Clone for FrameDataAndPoints
Sourcefn clone(&self) -> FrameDataAndPoints
fn clone(&self) -> FrameDataAndPoints
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrameDataAndPoints
impl Debug for FrameDataAndPoints
Sourceimpl PartialEq for FrameDataAndPoints
impl PartialEq for FrameDataAndPoints
impl StructuralPartialEq for FrameDataAndPoints